FreeBSD/ports 5a7f758security/strongswan pkg-plist Makefile, security/strongswan/files patch-conf_Makefile.in patch-src_libcharon_plugins_smp_smp.c

security/strongswan: Update 6.0.7 => 6.1.0

Changelog:
https://github.com/strongswan/strongswan/releases/tag/6.1.0

PR:             298372
MFH:            2026Q3
Security:       CVE-2026-78123
Security:       CVE-2026-78124
Security:       CVE-2026-78126
Security:       CVE-2026-78127
Security:       CVE-2026-78129
Security:       CVE-2026-78130
Security:       CVE-2026-78131
Security:       CVE-2026-78132
Security:       CVE-2026-78133
Security:       CVE-2026-78134
Security:       CVE-2026-78135
Sponsored by:   Rubicon Communications, LLC ("Netgate")
DeltaFile
+0-23security/strongswan/files/patch-src_libcharon_plugins_smp_smp.c
+3-3security/strongswan/distinfo
+0-5security/strongswan/pkg-plist
+2-3security/strongswan/Makefile
+2-2security/strongswan/files/patch-conf_Makefile.in
+7-365 files

FreeBSD/ports 2a88a73x11-fm/thunar Makefile distinfo

x11-fm/thunar: Update to 4.20.10
DeltaFile
+3-3x11-fm/thunar/distinfo
+1-1x11-fm/thunar/Makefile
+4-42 files

LLVM/project 8d2fef4

Merge branch 'users/ziqingluo/PR-187125348-3' of github.com:llvm/llvm-project into users/ziqingluo/PR-187125348-3

 Conflicts:
        clang/lib/ScalableStaticAnalysis/Analyses/PointerFlow/PointerFlowExtractor.cpp
        clang/lib/ScalableStaticAnalysis/SourceTransformation/Transformations/CppBoundedBuffers.cpp
DeltaFile
+0-00 files

LLVM/project 9a7259dclang/lib/ScalableStaticAnalysis/SourceTransformation CMakeLists.txt, clang/lib/ScalableStaticAnalysis/SourceTransformation/Transformations CppBoundedBuffers.cpp

[SSAF][clang-reforge] Retrofit expressions after CppBoundedBuffers decl rewrites

PR #210457 introduces declaration rewriting.  When CppBoundedBuffers
rewrites a declaration or return type to a bounded_ptr/bounded_array,
some of the existing uses of that entity needs retrofit.

This commit creates expression rewrites for the following patterns:

- Append '.data()' to call arguments when necessary parameter is not
  transformed but argument is transformed.
- Append '.as_bounded<T>()' to call arguments when both parameter and
  argument are transformed but element types are not identical.
- Rewrite '&e[i]' to '(e + i)' and '&*e'/'&(*e)' to 'e', if 'e' is
  transformed.
- Rewrite '(T*)e', 'static_cast<T*>(e)', and 'reinterpret_cast<T*>(e)'
  to 'e.as_bounded<T>()', if 'e' is transformed.

The 3rd step of
rdar://187125348
DeltaFile
+445-5clang/lib/ScalableStaticAnalysis/SourceTransformation/Transformations/CppBoundedBuffers.cpp
+246-1clang/unittests/ScalableStaticAnalysis/SourceTransformation/CppBoundedBuffersTest.cpp
+9-0clang/lib/ScalableStaticAnalysis/SourceTransformation/CMakeLists.txt
+7-0llvm/utils/gn/secondary/clang/lib/ScalableStaticAnalysis/SourceTransformation/BUILD.gn
+707-64 files

LLVM/project efe61a2clang/include/clang/ScalableStaticAnalysis/Analyses/EntityPointerLevel EntityPointerLevel.h, clang/include/clang/ScalableStaticAnalysis/Analyses/PointerFlow PointerFlowPairs.h

[SSAF][PointerFlow] Drop unused TUSummaryExtractor param from translateDeclPointerLevel

TUSummaryExtractor is only needed to mint EntityIds when building an
EntityPointerLevel; translateDeclPointerLevel just walks the Expr and
returns raw DeclPointerLevels, so it never touched Extractor.

This is the second patch the radar below depends on:
rdar://187125348
DeltaFile
+24-20clang/lib/ScalableStaticAnalysis/Analyses/EntityPointerLevel/EntityPointerLevel.cpp
+2-3clang/include/clang/ScalableStaticAnalysis/Analyses/EntityPointerLevel/EntityPointerLevel.h
+2-2clang/lib/ScalableStaticAnalysis/Analyses/PointerFlow/PointerFlowExtractor.cpp
+2-0clang/include/clang/ScalableStaticAnalysis/Analyses/PointerFlow/PointerFlowPairs.h
+30-254 files

LLVM/project 58b7d98clang/lib/ScalableStaticAnalysis/Analyses/PointerFlow PointerFlowExtractor.cpp

fix clang-format
DeltaFile
+1-2clang/lib/ScalableStaticAnalysis/Analyses/PointerFlow/PointerFlowExtractor.cpp
+1-21 files

LLVM/project a73dac5clang/include/clang/ScalableStaticAnalysis/Analyses/PointerFlow PointerFlowPairs.h, clang/lib/ScalableStaticAnalysis/Analyses SSAFAnalysesCommon.h

[SSAF][PointerFlow] Factor out and make the pointer-flow matching reusable

The PointerFlowExtractor matches AST nodes representing pointer-flows
and converts them to entity-based data structures directly. This
commit divides this procedure into two steps: 1) match and represent
AST nodes as PointerFlowPairs; 2) convert PointerFlowPairs to
entity-based edges. Therefore, other SSAF tools may use
PointerFlowPairs.

The refactoring also improves coverage: it separates pointer-type
checking from structural matching, so structural matching alone now
discovers cases that were previously missed due to overly aggressive
type checking (e.g. a record-typed call argument or return value
initialized with a braced-init-list).

Along the way, this also fixes a bug for unnamed bit-fields.

First patch for
rdar://187125348
DeltaFile
+433-0clang/unittests/ScalableStaticAnalysis/Analyses/PointerFlow/PointerFlowPairsTest.cpp
+300-0clang/lib/ScalableStaticAnalysis/Analyses/PointerFlow/PointerFlowPairs.cpp
+67-232clang/lib/ScalableStaticAnalysis/Analyses/PointerFlow/PointerFlowExtractor.cpp
+122-0clang/include/clang/ScalableStaticAnalysis/Analyses/PointerFlow/PointerFlowPairs.h
+7-1clang/lib/ScalableStaticAnalysis/Analyses/SSAFAnalysesCommon.h
+1-0llvm/utils/gn/secondary/clang/unittests/ScalableStaticAnalysis/BUILD.gn
+930-2333 files not shown
+933-2339 files

FreeBSD/src a22eb75sys/dev/tpm tpm_tis_core.c

tpm_tis: Quiesce interrupts before registering a handler

The current interrupt path uses the IRQ resource value directly as the
LPC SIRQ selector in TPM_INT_VECTOR and already restricts it to 1 through
15. This is a driver limitation: a parent interrupt number need not equal
an LPC SIRQ channel, and SPI TPMs can use a separate parallel interrupt.

On the reported system with ACPI IRQ 45, the existing range check runs
after handler registration and returns before disabling firmware interrupt
delivery. This can leave a polling device with a handler on an asserted
source.

Disable and verify interrupt delivery before registering a handler or
starting common TPM services. Preserve the existing range policy, using
polling without registering a handler for routes rejected by that check,
and release their IRQ resources. Keep a failed setup's potentially stale
output cookie out of the device state; the interrupt framework may
already have removed that handler.


    [19 lines not shown]
DeltaFile
+90-23sys/dev/tpm/tpm_tis_core.c
+90-231 files

LLVM/project 0485ad7clang/lib/CodeGen CodeGenModule.cpp, clang/test/CodeGen thread-model.c

clang: Emit the "thread-model" module flag (#223156)
DeltaFile
+11-0clang/test/CodeGen/thread-model.c
+9-0clang/lib/CodeGen/CodeGenModule.cpp
+20-02 files

LLVM/project 667efaellvm/lib/Transforms/InstCombine InstCombineCompares.cpp, llvm/test/Transforms/InstCombine icmp-rotate.ll

[InstCombine] Fix fold of comparison of rotates (#223263)

rotate(X, AmtX) == rotate(Y, AmtY) -> rotate(X, AmtX - AmtY) == Y

This fold is usually valid, but implicitly assumed that the bit width
was a power of two. This is now checked and the transform doesn't fire
if the bit width isn't a power of two.

Fixes https://github.com/llvm/llvm-project/issues/223262
DeltaFile
+12-6llvm/lib/Transforms/InstCombine/InstCombineCompares.cpp
+14-0llvm/test/Transforms/InstCombine/icmp-rotate.ll
+26-62 files

OpenBSD/ports qQ5d1b0security/vaultwarden Makefile crates.inc

   Update to vaultwarden-1.37.3

   Changes: https://github.com/dani-garcia/vaultwarden/releases/tag/1.37.3
VersionDeltaFile
1.40+278-258security/vaultwarden/distinfo
1.36+138-128security/vaultwarden/crates.inc
1.60+1-1security/vaultwarden/Makefile
+417-3873 files

Illumos/gate dcfd6a5usr/src/cmd/sunpc/other unix2dos.c dos2unix.c, usr/src/man/man1 dos2unix.1 unix2dos.1

15262 Files are optional for dos2unix/unix2dos
Reviewed by: Bill Sommerfeld <sommerfeld at hamachi.org>
Reviewed by: Toomas Soome <tsoome at me.com>
Approved by: Gordon Ross <gordon.w.ross at gmail.com>
DeltaFile
+9-30usr/src/man/man1/unix2dos.1
+8-29usr/src/man/man1/dos2unix.1
+4-1usr/src/cmd/sunpc/other/dos2unix.c
+3-1usr/src/cmd/sunpc/other/unix2dos.c
+24-614 files

LLVM/project 86858declang/test/Headers __clang_hip_math.hip, llvm/lib/Analysis ValueTracking.cpp

[ValueTracking] Propagate non-negativity through fptosi (#217868)

Fixes #217442

`fptosi` is poison when the rounded value does not fit in the result
type, so `computeKnownBits` can assume the conversion rounds towards
zero without wrapping. Negative subnormals and negative zero always
round to 0, so only sources known to never be a negative normal or
negative infinity (i.e. values <= -1.0) can produce a negative result.

This lets InstCombine fold `(int)fabs(x) < 0` to `false`, matching GCC,
and also benefits other magnitude-clamping intrinsics such as sqrt.
DeltaFile
+704-704clang/test/Headers/__clang_hip_math.hip
+65-0llvm/test/Transforms/InstCombine/fabs.ll
+21-0llvm/unittests/Analysis/ValueTrackingTest.cpp
+13-1llvm/lib/Analysis/ValueTracking.cpp
+14-0llvm/test/Transforms/InstCombine/sitofp.ll
+3-3llvm/test/CodeGen/AMDGPU/amdgpu-simplify-libcall-pow.ll
+820-7081 files not shown
+825-7087 files

LLVM/project 8e23b6dllvm/lib/Target/AMDGPU GCNCreateVOPD.cpp GCNVOPDUtils.cpp

[NFC][AMDGPU] Fix clang-tidy warnings in VOPD related files (#223261)
DeltaFile
+7-7llvm/lib/Target/AMDGPU/GCNVOPDUtils.cpp
+5-3llvm/lib/Target/AMDGPU/GCNCreateVOPD.cpp
+12-102 files

LLVM/project cba24d6llvm/lib/Transforms/Vectorize VPlanTransforms.cpp

[VPlan] Generalize folding IV increment into phi start value (NFC). (#223260)

simplifyRecipe folds

  X    = phi(0, IVInc)
  IVInc = X + Step
  Def   = IVInc + Y

into a phi starting at Y, but only if Y is a live-in. Also allow values
defined in the block the phi's start value is coming from, which is
where the value conservatively has to be available.

NFC today, but preparation for modeling the full epilogue skeleton in
VPlan.
DeltaFile
+20-13llvm/lib/Transforms/Vectorize/VPlanTransforms.cpp
+20-131 files

LLVM/project d44791dllvm/lib/Target/AMDGPU SIInstructions.td SIISelLowering.cpp, llvm/test/CodeGen/AMDGPU llvm.amdgcn.sched.barrier.ll

[AMDGPU] IGLP: Sanitize user schedule hints (#221256)

Fixes the following ICE:
```cpp
extern __shared__ int lds[];

__global__
void kern_ice() {
    auto _ = lds[threadIdx.x];
    __builtin_amdgcn_sched_barrier(~0x380); // Allow all except DS instructions
}
```

See: https://godbolt.org/z/oGfT1TTa4
DeltaFile
+0-22llvm/lib/Target/AMDGPU/AMDGPUIGroupLP.cpp
+22-0llvm/lib/Target/AMDGPU/AMDGPUIGroupLP.h
+6-0llvm/lib/Target/AMDGPU/SIISelLowering.cpp
+2-0llvm/test/CodeGen/AMDGPU/llvm.amdgcn.sched.barrier.ll
+2-0llvm/lib/Target/AMDGPU/SIInstructions.td
+32-225 files

LLVM/project 914e15cllvm/include/llvm/IR DebugInfoMetadata.h Metadata.h, llvm/lib/IR DebugInfoMetadata.cpp Metadata.cpp

[IR] Move the LLVMContext out of ReplaceableMetadataImpl. NFC (#222085)

No ReplaceableMetadataImpl method reads its LLVMContext reference, and
ValueAsMetadata reaches the context through the wrapped Value. Keep the
reference in a derived ReplaceableUsesWithContext, used by the two
owners with no other route to it: MDNode's on-demand RAUW support and
DIArgList.

Rename the base to ReplaceableUses: it is the use map behind RAUW for
the metadata kinds that support it, not a pimpl, and the name matches
ContextAndReplaceableUses and getReplaceableUses().

Make the base destructor protected, since getOrCreate() hands out
ReplaceableUses pointers that must never be deleted. Delete copy
assignment explicitly; the LLVMContext reference suppresses it
implicitly.

sizeof(ValueAsMetadata) 152 -> 144.
Aided by Opus 5
DeltaFile
+42-32llvm/include/llvm/IR/Metadata.h
+15-16llvm/lib/IR/Metadata.cpp
+4-4llvm/include/llvm/IR/DebugInfoMetadata.h
+4-3llvm/unittests/IR/MetadataTest.cpp
+1-1llvm/lib/Transforms/IPO/GlobalOpt.cpp
+1-1llvm/lib/IR/DebugInfoMetadata.cpp
+67-571 files not shown
+68-587 files

OpenBSD/ports l0hpmssgames/prismlauncher Makefile distinfo, games/prismlauncher/patches patch-launcher_minecraft_MinecraftInstance_cpp patch-launcher_CMakeLists_txt

   update to PrismLauncher 11.1.0

   Tested by MAINTAINER, myself, and izzy Meyer with b1.7.3, 1.20.6, 1.21.11 on amd64 and arm64.

   from MAINTAINER Daniil Ryvkin

   OK phessler@
VersionDeltaFile
1.2+3-3games/prismlauncher/pkg/MESSAGE
1.2+2-2games/prismlauncher/patches/patch-launcher_HardwareInfo_cpp
1.2+2-2games/prismlauncher/distinfo
1.2+1-1games/prismlauncher/patches/patch-launcher_minecraft_MinecraftInstance_cpp
1.2+1-1games/prismlauncher/patches/patch-launcher_CMakeLists_txt
1.2+1-1games/prismlauncher/Makefile
+10-106 files

OPNSense/core ee367f5src/opnsense/mvc/app/models/OPNsense/Core/ACL ACL.xml

interfaces: fix API ACL patters for GIF/GRE; closes #10871
DeltaFile
+2-2src/opnsense/mvc/app/models/OPNsense/Core/ACL/ACL.xml
+2-21 files

LLVM/project b7877e0llvm/lib/Transforms/Scalar ConstraintElimination.cpp, llvm/test/Transforms/ConstraintElimination induction-relational-predicate-latch.ll

[ConstraintElim] Derive an unsigned IV bound from a signed relational latch. (#222762)

For a known non-negative backedge (either via isKnownNonNegative or
because the increment is increasing), 0 <=s PN <= B holds and implies
that B is non-negative as well.

Use that to translate a signed condition to the equivalent unsigned one.

Note that the general signed->unsigned rewrite cannot catch this,
because the precondition also needs rewriting to unsigned.

No llvm-opt-benchmark-nightly impact, but it can help remove runtime
checks generated by sanitizers or Swift code. An end-to-end C example is
https://clang.godbolt.org/z/vbd91MjaM.

Alive2 Proof:  https://alive2.llvm.org/ce/z/G3Mv7t

PR: https://github.com/llvm/llvm-project/pull/222762
DeltaFile
+243-0llvm/test/Transforms/ConstraintElimination/induction-relational-predicate-latch.ll
+15-0llvm/lib/Transforms/Scalar/ConstraintElimination.cpp
+258-02 files

LLVM/project 4098f56mlir/lib/Dialect/Vector/IR VectorOps.cpp, mlir/test/Dialect/Vector canonicalize.mlir

[mlir][vector] Don't fold in_bounds for negative constant indices (#219681)

`isInBounds` checked only that the transfer *ends* inside the source:

    return cstOp.value() + vectorSize <= sourceSize;

The `in_bounds` attribute promises more than that. Its definition in
VectorOps.td says accesses "(including the starting point)" may run
out-of-bounds when it is "false", so setting it to "true" is a claim
about the start of the transfer as well as its end.

With a negative constant index the two disagree. For

    vector.transfer_read %m[-1] : memref<8xf32>, vector<4xf32>

`-1 + 4 <= 8` holds, so the fold set `in_bounds = [true]`, even though
element -1 is read from outside `%m`.

The same expression also overflows for a large enough index: at `index =

    [13 lines not shown]
DeltaFile
+39-0mlir/test/Dialect/Vector/canonicalize.mlir
+9-1mlir/lib/Dialect/Vector/IR/VectorOps.cpp
+48-12 files

HardenedBSD/ports 1313206net-im/signal-desktop/files pnpm-lock.yaml, science/ttk pkg-plist

Merge branch 'freebsd/main' into hardenedbsd/main
DeltaFile
+53,785-0www/hedgedoc/pkg-plist
+1,078-659net-im/signal-desktop/files/pnpm-lock.yaml
+941-0x11-wm/halley/distinfo
+469-0x11-wm/halley/Makefile.crates
+241-2science/ttk/pkg-plist
+115-0www/hedgedoc/Makefile
+56,629-661104 files not shown
+57,554-894110 files

LLVM/project 053b3dbllvm/lib/Target/AMDGPU GCNCreateVOPD.cpp GCNVOPDUtils.cpp

[NFC][AMDGPU] Fix clang-tidy warnings in VOPD related files
DeltaFile
+7-7llvm/lib/Target/AMDGPU/GCNVOPDUtils.cpp
+5-3llvm/lib/Target/AMDGPU/GCNCreateVOPD.cpp
+12-102 files

LLVM/project 85f694bllvm/lib/Transforms/Instrumentation AddressSanitizer.cpp, llvm/test/Instrumentation/AddressSanitizer asan-detect-invalid-pointer-pair.ll

[ASan] Convert pointer-pair operands based on type (#218494)

`CreatePointerCast` was being called on everything without checking what
it actually is, so if the operand came from ptrtoint ... to i32 it just
crashes (its not a pointer).

now it check the type first - pointers get pointer-cast, ints get
zext/trunc'd to intptr width.

Fixes #217544

also edited regression tests for this
DeltaFile
+27-0llvm/test/Instrumentation/AddressSanitizer/asan-detect-invalid-pointer-pair.ll
+13-1llvm/lib/Transforms/Instrumentation/AddressSanitizer.cpp
+40-12 files

NetBSD/src CVk4rPpsys/dev/pci pci_resource.c

   pci_resource: use existing BARs even if mem/io space is left disabled

   It's possible that firmware assigned resources to a device and left
   memory / io space accesses disabled. Let's assume if we see a non-zero
   address in a BAR that it was assigned by firmware.

   Should help PR# kern/60427 and kern/60463
VersionDeltaFile
1.8+11-2sys/dev/pci/pci_resource.c
+11-21 files

NetBSD/pkgsrc-wip b817fd5forgejo Makefile go-modules.mk

forgejo: update to 16.0.4.
DeltaFile
+81-84forgejo/distinfo
+26-27forgejo/go-modules.mk
+1-1forgejo/Makefile
+108-1123 files

FreeBSD/ports 44f8819graphics/shotwell distinfo pkg-plist, graphics/shotwell/files patch-meson.build

graphics/shotwell: update to 33.0

Release Notes:
  https://gitlab.gnome.org/GNOME/shotwell/-/blob/33.0/NEWS?ref_type=tags
DeltaFile
+12-12graphics/shotwell/Makefile
+20-0graphics/shotwell/files/patch-meson.build
+5-8graphics/shotwell/pkg-plist
+3-3graphics/shotwell/distinfo
+40-234 files

HardenedBSD/ports 44f8819graphics/shotwell distinfo pkg-plist, graphics/shotwell/files patch-meson.build

graphics/shotwell: update to 33.0

Release Notes:
  https://gitlab.gnome.org/GNOME/shotwell/-/blob/33.0/NEWS?ref_type=tags
DeltaFile
+12-12graphics/shotwell/Makefile
+20-0graphics/shotwell/files/patch-meson.build
+5-8graphics/shotwell/pkg-plist
+3-3graphics/shotwell/distinfo
+40-234 files

LLVM/project 8864a4bllvm/lib/Target/Mips MipsInstrInfo.td MipsISelLowering.cpp, llvm/test/CodeGen/Mips/llvm-ir udiv.ll srem.ll

[Mips] Handle division by zero trap on MIPS1 (#201133)

LLVM currently emits the `teq` instruction for every arch version, but
`teq` is unsupported on MIPS1.
This special cases MIPS1 so that `bne(z)` and `break` are emitted
instead.
Compared to https://github.com/llvm/llvm-project/pull/81311, this should
also handle liveness as far as I can tell.

I didn't want to add another bool to the argument list so I combined
`IsMicroMips` and what was supposed to be `IsMips1` into an enum, which
feels much nicer in this case.
Besides that and the main change, I also changed the `hasSideEffects`
bit for `PseudoSDIV` and `PseudoUDIV`,
which allows the delay slot to be usefully filled - well, at least with
`-O1`+. This seems to be in line with what GCC does:
https://godbolt.org/z/zqcG5ha35

Tested using clang directly and through Zig's LLVM backend.

    [2 lines not shown]
DeltaFile
+92-0llvm/test/CodeGen/Mips/llvm-ir/urem.ll
+88-0llvm/test/CodeGen/Mips/llvm-ir/sdiv.ll
+86-0llvm/test/CodeGen/Mips/llvm-ir/udiv.ll
+86-0llvm/test/CodeGen/Mips/llvm-ir/srem.ll
+65-10llvm/lib/Target/Mips/MipsISelLowering.cpp
+2-2llvm/lib/Target/Mips/MipsInstrInfo.td
+419-126 files

HardenedBSD/src a6b40d7sys/compat/linuxkpi/common/include/linux scatterlist.h, sys/compat/linuxkpi/common/src linux_pci.c

LinuxKPI: Add dma_length field to struct scatterlist

On Linux `dma_length` field of `struct scatterlist` is present on the
arches where DMA mapping code is able to coalesce adjacent segments
of physical address space. It contains total length of coalesced
segments while `length` field contains non-coalesced length of each
segment. On other arches `dma_length` is aliased to `length` field with
`sg_dma_len` macro. As FreeBSD does not merge scatterlist segments it
do not have `dma_length` field. It is appered that at least i915kms
driver depends on existence of `dma_length` field.

Add the field and disable it by default. To enable add to Makefile

.if ${MACHINE_CPUARCH} == "i386" || ${MACHINE_CPUARCH} == "amd64" || \\
    ${MACHINE_CPUARCH} == "aarch64" || ${MACHINE_CPUARCH} == "powerpc"
CFLAGS+=        -DCONFIG_NEED_SG_DMA_LENGTH
.endif

Reported by:    Ryan Fahy

    [4 lines not shown]
DeltaFile
+17-9sys/compat/linuxkpi/common/include/linux/scatterlist.h
+1-0sys/compat/linuxkpi/common/src/linux_pci.c
+18-92 files